#!/usr/bin/python
# -*- coding: utf-8 -*-

# Libervia: a Salut à Toi frontend
# Copyright (C) 2011, 2012, 2013, 2014 Jérôme Poisson <goffi@goffi.org>

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# FIXME: Libervia should use sat_frontends.tools.jid but pyjamas doesn't
# know the unicode type and also experiences issues with __new__.


class JID(object):
    """This class help manage JID (Node@Domaine/Resource)"""

    def __init__(self, jid):
        self.__raw = str(self.__normalize(jid))
        self.__parse()

    @classmethod
    def __normalize(cls, jid):
        """Naive normalization before instantiating and parsing the JID"""
        if not jid:
            return jid
        tokens = jid.split('/')
        tokens[0] = tokens[0].lower()  # force node and domain to lower-case
        return '/'.join(tokens)

    def __parse(self):
        """Find node domain and resource"""
        node_end = self.__raw.find('@')
        if node_end < 0:
            node_end = 0
        domain_end = self.__raw.find('/')
        if domain_end < 1:
            domain_end = len(self.__raw)
        self.node = self.__raw[:node_end]
        self.domain = self.__raw[(node_end + 1) if node_end else 0:domain_end]
        self.resource = self.__raw[domain_end + 1:]
        if not node_end:
            self.bare = self.__raw
        else:
            self.bare = self.node + '@' + self.domain

    def __str__(self):
        return self.__raw.__str__()

    def is_valid(self):
        """
        @return: True if the JID is XMPP compliant
        """
        #FIXME: always return True for the moment
        return self.domain != ''

    def __eq__(self, other):
        """Redefine equality operator to implement the naturally expected test"""
        return self.node == other.node and self.domain == other.domain and self.resource == other.resource
